from django.core.management.base import BaseCommand
from django.contrib.auth.models import User
import secrets
import string
from reinhardt.helpers import user_preferences
from django.urls import reverse
from django.conf import settings


def make_token() -> str:
    alphabet = string.ascii_letters + string.digits
    return "".join(secrets.choice(alphabet) for i in range(64))


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument("username", type=str)

    def handle(self, *args, **options):
        username = options["username"].strip().lower()
        user, _ = User.objects.get_or_create(username=username)
        prefs = user_preferences(user)
        if not prefs.access_token:
            prefs.access_token = make_token()
            prefs.save()
        print(
            settings.ACCESS_URL_PREFIX + reverse("invite") + "?q=" + prefs.access_token
        )
