// Unpoly conf.
up.link.config.followSelectors.push('a[href]');
up.link.config.preloadSelectors.push('a[href]');
up.form.config.submitSelectors.push(['form']);
up.fragment.config.runScripts = false;

// bootstrap: Use system light/dark mode
;(function () {
    const htmlElement = document.querySelector("html");
    if (htmlElement.getAttribute("data-bs-theme") === 'auto') {
        function updateTheme() {
            document.querySelector("html").setAttribute("data-bs-theme",
                window.matchMedia("(prefers-color-scheme: dark)").matches ? "dark" : "light");
        }

        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', updateTheme)
        updateTheme();
    }
})();

function getPlayer() {
    return document.getElementById("player");
}

function togglePlayer() {
    let player = getPlayer();
    if (player.getAttribute("controls")) {
        player.removeAttribute("controls");
    } else {
        player.setAttribute("controls", "controls");
    }
}

function unblinkPlayer() {
    let blinky_playing_icon = document.getElementById("blinky_icon");
    if (blinky_playing_icon) {
        blinky_playing_icon.classList.remove("blink");
    }
}

function playQueueItem(element) {
    getPlayer().pause();
    unblinkPlayer();
    document.getElementById("queue_next_track").value = "";
    document.getElementById("queue_list_item").value = element.closest(".list-group-item").dataset.itempk;
    up.submit("#now_playing_form");
}


function removeFromQueue(element){
    let item = element.closest(".list-group-item");
    document.getElementById("queue_remove_item").value = item.dataset.itempk;
    up.submit("#queue_remove_form");
    item.remove()
    let counter = document.getElementById("track_count");
    counter.innerText = String(parseInt(counter.innerText) - 1);
}


function playNext(insertTrack) {
    getPlayer().pause();
    unblinkPlayer();
    document.getElementById("queue_list_item").value = "";
    if (insertTrack !== undefined) {
        document.getElementById("queue_next_track").value = insertTrack;
    } else {
        document.getElementById("queue_next_track").value = "";
    }
    up.submit('#now_playing_form');
}

// play next track when previous has ended
getPlayer().addEventListener("ended", function (evt) {
    playNext();
});

// when track is removed from favorites, also remove from page if page is favorites
up.compiler('.music_file_removed_from_favorite', function (element) {
    if (document.getElementById("page_context")) {
        if (document.getElementById("page_context").value === "favorites") {
            let trackid = element.dataset.objectpk;
            document.getElementById("music_files_row_" + trackid).remove();
            let counter = document.getElementById("track_count");
            counter.innerText = String(parseInt(counter.innerText) - 1);
        }
    }
});

// when track is removed from page tag, also remove from page if page is tag
up.compiler('.music_file_removed_from_tag', function (element) {
    if (document.getElementById("page_context")) {
        if (document.getElementById("page_context").value === "tag") {
            let trackid = element.dataset.objectpk;
            document.getElementById("music_files_row_" + trackid).remove();
            let counter = document.getElementById("track_count");
            counter.innerText = String(parseInt(counter.innerText) - 1);
        }
    }
});

// when new track loaded in now_playing, start player
up.compiler("#now_playing", function (element) {
    if (element.dataset.url) {
        let player = getPlayer();
        player.src = element.dataset.url;
        player.play();
    }
    if (document.getElementById("page_context") &&
        document.getElementById("page_context").value === "queue") {
        up.follow(document.querySelector('#link_refresh_queue'), {
            scroll: false
        })
    }
});

up.compiler(".makeMeSortable", function (element) {
    let sortable = Sortable.create(element, {
        "onUpdate": function () {
            let positions = [];
            let list_items = Array.from(document.querySelectorAll(".queue_item"));
            for (let i = 0; i < list_items.length; i++) {
                positions.push({rank: i + 1, item: parseInt(list_items[i].dataset.itempk)})
            }
            document.getElementById("queue_new_order").value = JSON.stringify(positions);
            up.submit(document.getElementById("queue_order_form"));
        },
        "handle": ".sortable_handle"
    });
});

// reload dropdown menu every time dropdown button is pressed
document.body.addEventListener('mousedown', event => {
    if (event.target.classList.contains("track_menu")) {
        let page_context = ""
        if (document.getElementById("page_context")) {
            page_context = document.getElementById("page_context").value;
        }
        let trackid = event.target.dataset.trackid;
        let remove_from_tag = event.target.dataset.remove_from_tag;
        let playing = event.target.dataset.playing;
        let target_elements = Array.prototype.slice.call(document.getElementsByClassName("dropdown-menu-" + trackid));
        fetch(dropdown_url + "?q=" + trackid + "&tag=" + remove_from_tag + "&playing=" + playing + "&context=" + page_context, {method: "GET"})
            .then(response => response)
            .then(response => response.text())
            .then(function (body) {
                for (let i = 0; i < target_elements.length; i++) {
                    target_elements[i].innerHTML = body;
                }
                if (document.getElementById("page_context")) {
                    if (document.getElementById("page_context").value === "favorites") {
                        let add_form = document.getElementById("form_add_music_file_" + trackid + "_to_favorite");
                        if (add_form) {
                            document.getElementById("music_files_row_" + trackid).remove();
                        }
                    }
                }
            });
    }
});

document.body.addEventListener("keypress", function (evt) {
    if (!evt.target.classList.contains("form-control")) {
        evt.preventDefault();
        let playa = getPlayer();
        if (evt.key === "n") {
            playNext()
        }
        if (evt.key === "p") {
            // TODO: change player icon, stop blinking
            playa.pause();
        }
        if (evt.key === "s") {
            // TODO: change player icon, stop blinking
            playa.pause();
            playa.fastSeek(0);
        }
    }
});